@@ -1,19 +1,22 @@
 from collections import OrderedDict
 from dataclasses import dataclass, field
+from typing import Dict, Optional
 
 HASH_DIR_SUFFIX = ".dir"
 
+DirInfo = Dict[str, str]
+
 
 @dataclass
 class HashInfo:
     PARAM_SIZE = "size"
     PARAM_NFILES = "nfiles"
 
-    name: str
-    value: str
-    dir_info: dict = field(default=None, compare=False)
-    size: int = field(default=None, compare=False)
-    nfiles: int = field(default=None, compare=False)
+    name: Optional[str]
+    value: Optional[str]
+    dir_info: Optional[DirInfo] = field(default=None, compare=False)
+    size: Optional[int] = field(default=None, compare=False)
+    nfiles: Optional[int] = field(default=None, compare=False)
 
     def __bool__(self):
         return bool(self.value)
